Struct rkyv::rc::ArchivedRc [−][src]
#[repr(transparent)]pub struct ArchivedRc<T: ArchivePointee + ?Sized, F>(_, _);Expand description
An archived Rc.
This is a thin wrapper around a RelPtr to the archived type paired with a “flavor” type.
Because there may be many varieties of shared pointers and they may not be used together, the
flavor helps check that memory is not being shared incorrectly during validation.
Implementations
Gets the pinned mutable value of this ArchivedRc.
Safety
Any other ArchivedRc pointers to the same value must not be dereferenced for the duration
of the returned borrow.
pub unsafe fn resolve_from_ref<U: ArchiveUnsized<Archived = T> + ?Sized>(
value: &U,
pos: usize,
resolver: RcResolver<MetadataResolver<U>>,
out: *mut Self
)
pub unsafe fn resolve_from_ref<U: ArchiveUnsized<Archived = T> + ?Sized>(
value: &U,
pos: usize,
resolver: RcResolver<MetadataResolver<U>>,
out: *mut Self
)
Resolves an archived Rc from a given reference.
Safety
posmust be the position ofoutwithin the archiveresolvermust be the result of serializingvalue
pub fn serialize_from_ref<U: SerializeUnsized<S> + ?Sized, S: Serializer + SharedSerializeRegistry + ?Sized>(
value: &U,
serializer: &mut S
) -> Result<RcResolver<MetadataResolver<U>>, S::Error>
pub fn serialize_from_ref<U: SerializeUnsized<S> + ?Sized, S: Serializer + SharedSerializeRegistry + ?Sized>(
value: &U,
serializer: &mut S
) -> Result<RcResolver<MetadataResolver<U>>, S::Error>
Serializes an archived Rc from a given reference.